# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/build/v1/build_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.build.v1 import build_pb2 as qwak_dot_build_dot_v1_dot_build__pb2
from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2
from _qwak_proto.qwak.fitness_service import fitness_pb2 as qwak_dot_fitness__service_dot_fitness__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dqwak/build/v1/build_api.proto\x12\x11\x63om.qwak.build.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19qwak/build/v1/build.proto\x1a/qwak/user_application/common/v0/resources.proto\x1a\"qwak/fitness_service/fitness.proto\"R\n\x1aSaveFrameworkModelsRequest\x12\x34\n\x04spec\x18\x01 \x01(\x0b\x32&.com.qwak.build.v1.FrameworkModelsSpec\"\x1d\n\x1bSaveFrameworkModelsResponse\"|\n\x14RegisterBuildRequest\x12\x0f\n\x07\x62uildId\x18\x01 \x01(\t\x12\x10\n\x08\x63ommitId\x18\x02 \x01(\t\x12\x0f\n\x07modelId\x18\x03 \x01(\t\x12\x13\n\x0b\x62uildConfig\x18\x04 \x01(\t\x12\x0c\n\x04tags\x18\x05 \x03(\t\x12\r\n\x05steps\x18\x06 \x03(\t\"\x17\n\x15RegisterBuildResponse\"a\n\x18UpdateBuildStatusRequest\x12\x0f\n\x07\x62uildId\x18\x01 \x01(\t\x12\x34\n\x0c\x62uild_status\x18\x02 \x01(\x0e\x32\x1e.com.qwak.build.v1.BuildStatus\"\x1b\n\x19UpdateBuildStatusResponse\"\xba\x02\n!RegisterExperimentTrackingRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12P\n\x06params\x18\x02 \x03(\x0b\x32@.com.qwak.build.v1.RegisterExperimentTrackingRequest.ParamsEntry\x12R\n\x07metrics\x18\x03 \x03(\x0b\x32\x41.com.qwak.build.v1.RegisterExperimentTrackingRequest.MetricsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"$\n\"RegisterExperimentTrackingResponse\"d\n\x1aRegisterModelSchemaRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x34\n\x0cmodel_schema\x18\x02 \x01(\x0b\x32\x1e.com.qwak.build.v1.ModelSchema\"\x1d\n\x1bRegisterModelSchemaResponse\"#\n\x0fGetBuildRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\";\n\x10GetBuildResponse\x12\'\n\x05\x62uild\x18\x01 \x01(\x0b\x32\x18.com.qwak.build.v1.Build\"n\n\x11ListBuildsRequest\x12\x15\n\tbranch_id\x18\x01 \x01(\tB\x02\x18\x01\x12.\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1e.com.qwak.build.v1.BuildFilter\x12\x12\n\nmodel_uuid\x18\x03 \x01(\t\"=\n\x12ListBuildsResponse\x12\'\n\x05\x62uild\x18\x01 \x03(\x0b\x32\x18.com.qwak.build.v1.Build\"5\n\x13RegisterTagsRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x0c\n\x04tags\x18\x02 \x03(\t\"\x16\n\x14RegisterTagsResponse\"\x8e\x01\n\x15LogPhaseStatusRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x10\n\x08phase_id\x18\x02 \x01(\t\x12.\n\x06status\x18\x03 \x01(\x0e\x32\x1e.com.qwak.build.v1.PhaseStatus\x12!\n\x19phase_duration_in_seconds\x18\x04 \x01(\x05\"\x18\n\x16LogPhaseStatusResponse\"+\n\x17GetPhaseStatusesRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"\x99\x02\n\x0ePhaseStatusLog\x12\x10\n\x08phase_id\x18\x01 \x01(\t\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x1e.com.qwak.build.v1.PhaseStatus\x12!\n\x19phase_duration_in_seconds\x18\x03 \x01(\x05\x12<\n\x12pod_failure_reason\x18\x04 \x01(\x0e\x32 .com.qwak.build.v1.FailureReason\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"O\n\x18GetPhaseStatusesResponse\x12\x33\n\x08statuses\x18\x01 \x03(\x0b\x32!.com.qwak.build.v1.PhaseStatusLog\"\'\n\x12\x44\x65leteBuildRequest\x12\x11\n\tbuild_ids\x18\x01 \x03(\t\"\x15\n\x13\x44\x65leteBuildResponse\"a\n\x11GetTagPathRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12\x10\n\x08tag_name\x18\x04 \x01(\t\"&\n\x12GetTagPathResponse\x12\x10\n\x08key_path\x18\x01 \x01(\t\"\xa4\x02\n\x1dRerunBuildFromExistingRequest\x12\x19\n\x11\x65xisting_build_id\x18\x01 \x01(\t\x12\x46\n\x17new_build_configuration\x18\x02 \x01(\x0b\x32%.com.qwak.build.v1.BuildConfiguration\x12M\n\tresources\x18\x03 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\x12=\n\x0fpurchase_option\x18\x04 \x01(\x0e\x32$.qwak.fitness.service.PurchaseOption\x12\x12\n\nbuild_name\x18\x05 \x01(\t\" \n\x1eRerunBuildFromExistingResponse\"S\n$GetBuildsArtifactsScanSummaryRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x19\n\rartifact_name\x18\x02 \x01(\tB\x02\x18\x01\"\xd5\x02\n%GetBuildsArtifactsScanSummaryResponse\x12\x38\n\x06result\x18\x01 \x01(\x0b\x32$.com.qwak.build.v1.ScanResultSummaryB\x02\x18\x01\x12\x1a\n\x0eui_direct_link\x18\x02 \x01(\tB\x02\x18\x01\x12s\n\x17result_by_artifact_name\x18\x03 \x03(\x0b\x32R.com.qwak.build.v1.GetBuildsArtifactsScanSummaryResponse.ResultByArtifactNameEntry\x1a\x61\n\x19ResultByArtifactNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.com.qwak.build.v1.ScanResultSummary:\x02\x38\x01\"G\n\x1bGetBuildImageDetailsRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"a\n\x1cGetBuildImageDetailsResponse\x12\x41\n\x13\x62uild_image_details\x18\x01 \x01(\x0b\x32$.com.qwak.build.v1.BuildImageDetails\">\n\x16UpdateBuildNameRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x12\n\nbuild_name\x18\x02 \x01(\t\"\x19\n\x17UpdateBuildNameResponse\"p\n\x1dGetBuildsArtifactsScanRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12=\n\x11scan_request_type\x18\x02 \x01(\x0b\x32\".com.qwak.build.v1.ScanRequestType\"2\n\x1eGetBuildsArtifactsScanResponse\x12\x10\n\x08raw_data\x18\x01 \x01(\t*\x97\x01\n\x0bPhaseStatus\x12\x18\n\x14PHASE_STATUS_INVALID\x10\x00\x12\x1c\n\x18PHASE_STATUS_IN_PROGRESS\x10\x01\x12\x1b\n\x17PHASE_STATUS_SUCCESSFUL\x10\x02\x12\x17\n\x13PHASE_STATUS_FAILED\x10\x03\x12\x1a\n\x16PHASE_STATUS_CANCELLED\x10\x04*w\n\rFailureReason\x12\x1e\n\x1a\x46\x41ILURE_REASON_UNSPECIFIED\x10\x00\x12$\n FAILURE_REASON_AVAILABLE_IN_LOGS\x10\x01\x12 \n\x1c\x46\x41ILURE_REASON_OUT_OF_MEMORY\x10\x02\x32\xea\x0e\n\x08\x42uildAPI\x12\x62\n\rRegisterBuild\x12\'.com.qwak.build.v1.RegisterBuildRequest\x1a(.com.qwak.build.v1.RegisterBuildResponse\x12n\n\x11UpdateBuildStatus\x12+.com.qwak.build.v1.UpdateBuildStatusRequest\x1a,.com.qwak.build.v1.UpdateBuildStatusResponse\x12\x89\x01\n\x1aRegisterExperimentTracking\x12\x34.com.qwak.build.v1.RegisterExperimentTrackingRequest\x1a\x35.com.qwak.build.v1.RegisterExperimentTrackingResponse\x12_\n\x0cRegisterTags\x12&.com.qwak.build.v1.RegisterTagsRequest\x1a\'.com.qwak.build.v1.RegisterTagsResponse\x12t\n\x13RegisterModelSchema\x12-.com.qwak.build.v1.RegisterModelSchemaRequest\x1a..com.qwak.build.v1.RegisterModelSchemaResponse\x12S\n\x08GetBuild\x12\".com.qwak.build.v1.GetBuildRequest\x1a#.com.qwak.build.v1.GetBuildResponse\x12Y\n\nListBuilds\x12$.com.qwak.build.v1.ListBuildsRequest\x1a%.com.qwak.build.v1.ListBuildsResponse\x12\\\n\x0b\x44\x65leteBuild\x12%.com.qwak.build.v1.DeleteBuildRequest\x1a&.com.qwak.build.v1.DeleteBuildResponse\x12\x65\n\x0eLogPhaseStatus\x12(.com.qwak.build.v1.LogPhaseStatusRequest\x1a).com.qwak.build.v1.LogPhaseStatusResponse\x12k\n\x10GetPhaseStatuses\x12*.com.qwak.build.v1.GetPhaseStatusesRequest\x1a+.com.qwak.build.v1.GetPhaseStatusesResponse\x12Y\n\nGetTagPath\x12$.com.qwak.build.v1.GetTagPathRequest\x1a%.com.qwak.build.v1.GetTagPathResponse\x12}\n\x16RerunBuildFromExisting\x12\x30.com.qwak.build.v1.RerunBuildFromExistingRequest\x1a\x31.com.qwak.build.v1.RerunBuildFromExistingResponse\x12t\n\x13SaveFrameworkModels\x12-.com.qwak.build.v1.SaveFrameworkModelsRequest\x1a..com.qwak.build.v1.SaveFrameworkModelsResponse\x12\x92\x01\n\x1dGetBuildsArtifactsScanSummary\x12\x37.com.qwak.build.v1.GetBuildsArtifactsScanSummaryRequest\x1a\x38.com.qwak.build.v1.GetBuildsArtifactsScanSummaryResponse\x12w\n\x14GetBuildImageDetails\x12..com.qwak.build.v1.GetBuildImageDetailsRequest\x1a/.com.qwak.build.v1.GetBuildImageDetailsResponse\x12h\n\x0fUpdateBuildName\x12).com.qwak.build.v1.UpdateBuildNameRequest\x1a*.com.qwak.build.v1.UpdateBuildNameResponse\x12}\n\x16GetBuildsArtifactsScan\x12\x30.com.qwak.build.v1.GetBuildsArtifactsScanRequest\x1a\x31.com.qwak.build.v1.GetBuildsArtifactsScanResponseB$\n\x11\x63om.qwak.build.v1B\rBuildApiProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.build.v1.build_api_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021com.qwak.build.v1B\rBuildApiProtoP\001'
  _REGISTEREXPERIMENTTRACKINGREQUEST_PARAMSENTRY._options = None
  _REGISTEREXPERIMENTTRACKINGREQUEST_PARAMSENTRY._serialized_options = b'8\001'
  _REGISTEREXPERIMENTTRACKINGREQUEST_METRICSENTRY._options = None
  _REGISTEREXPERIMENTTRACKINGREQUEST_METRICSENTRY._serialized_options = b'8\001'
  _LISTBUILDSREQUEST.fields_by_name['branch_id']._options = None
  _LISTBUILDSREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _GETBUILDSARTIFACTSSCANSUMMARYREQUEST.fields_by_name['artifact_name']._options = None
  _GETBUILDSARTIFACTSSCANSUMMARYREQUEST.fields_by_name['artifact_name']._serialized_options = b'\030\001'
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE_RESULTBYARTIFACTNAMEENTRY._options = None
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE_RESULTBYARTIFACTNAMEENTRY._serialized_options = b'8\001'
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE.fields_by_name['result']._options = None
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE.fields_by_name['result']._serialized_options = b'\030\001'
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE.fields_by_name['ui_direct_link']._options = None
  _GETBUILDSARTIFACTSSCANSUMMARYRESPONSE.fields_by_name['ui_direct_link']._serialized_options = b'\030\001'
  _globals['_PHASESTATUS']._serialized_start=3403
  _globals['_PHASESTATUS']._serialized_end=3554
  _globals['_FAILUREREASON']._serialized_start=3556
  _globals['_FAILUREREASON']._serialized_end=3675
  _globals['_SAVEFRAMEWORKMODELSREQUEST']._serialized_start=197
  _globals['_SAVEFRAMEWORKMODELSREQUEST']._serialized_end=279
  _globals['_SAVEFRAMEWORKMODELSRESPONSE']._serialized_start=281
  _globals['_SAVEFRAMEWORKMODELSRESPONSE']._serialized_end=310
  _globals['_REGISTERBUILDREQUEST']._serialized_start=312
  _globals['_REGISTERBUILDREQUEST']._serialized_end=436
  _globals['_REGISTERBUILDRESPONSE']._serialized_start=438
  _globals['_REGISTERBUILDRESPONSE']._serialized_end=461
  _globals['_UPDATEBUILDSTATUSREQUEST']._serialized_start=463
  _globals['_UPDATEBUILDSTATUSREQUEST']._serialized_end=560
  _globals['_UPDATEBUILDSTATUSRESPONSE']._serialized_start=562
  _globals['_UPDATEBUILDSTATUSRESPONSE']._serialized_end=589
  _globals['_REGISTEREXPERIMENTTRACKINGREQUEST']._serialized_start=592
  _globals['_REGISTEREXPERIMENTTRACKINGREQUEST']._serialized_end=906
  _globals['_REGISTEREXPERIMENTTRACKINGREQUEST_PARAMSENTRY']._serialized_start=813
  _globals['_REGISTEREXPERIMENTTRACKINGREQUEST_PARAMSENTRY']._serialized_end=858
  _globals['_REGISTEREXPERIMENTTRACKINGREQUEST_METRICSENTRY']._serialized_start=860
  _globals['_REGISTEREXPERIMENTTRACKINGREQUEST_METRICSENTRY']._serialized_end=906
  _globals['_REGISTEREXPERIMENTTRACKINGRESPONSE']._serialized_start=908
  _globals['_REGISTEREXPERIMENTTRACKINGRESPONSE']._serialized_end=944
  _globals['_REGISTERMODELSCHEMAREQUEST']._serialized_start=946
  _globals['_REGISTERMODELSCHEMAREQUEST']._serialized_end=1046
  _globals['_REGISTERMODELSCHEMARESPONSE']._serialized_start=1048
  _globals['_REGISTERMODELSCHEMARESPONSE']._serialized_end=1077
  _globals['_GETBUILDREQUEST']._serialized_start=1079
  _globals['_GETBUILDREQUEST']._serialized_end=1114
  _globals['_GETBUILDRESPONSE']._serialized_start=1116
  _globals['_GETBUILDRESPONSE']._serialized_end=1175
  _globals['_LISTBUILDSREQUEST']._serialized_start=1177
  _globals['_LISTBUILDSREQUEST']._serialized_end=1287
  _globals['_LISTBUILDSRESPONSE']._serialized_start=1289
  _globals['_LISTBUILDSRESPONSE']._serialized_end=1350
  _globals['_REGISTERTAGSREQUEST']._serialized_start=1352
  _globals['_REGISTERTAGSREQUEST']._serialized_end=1405
  _globals['_REGISTERTAGSRESPONSE']._serialized_start=1407
  _globals['_REGISTERTAGSRESPONSE']._serialized_end=1429
  _globals['_LOGPHASESTATUSREQUEST']._serialized_start=1432
  _globals['_LOGPHASESTATUSREQUEST']._serialized_end=1574
  _globals['_LOGPHASESTATUSRESPONSE']._serialized_start=1576
  _globals['_LOGPHASESTATUSRESPONSE']._serialized_end=1600
  _globals['_GETPHASESTATUSESREQUEST']._serialized_start=1602
  _globals['_GETPHASESTATUSESREQUEST']._serialized_end=1645
  _globals['_PHASESTATUSLOG']._serialized_start=1648
  _globals['_PHASESTATUSLOG']._serialized_end=1929
  _globals['_GETPHASESTATUSESRESPONSE']._serialized_start=1931
  _globals['_GETPHASESTATUSESRESPONSE']._serialized_end=2010
  _globals['_DELETEBUILDREQUEST']._serialized_start=2012
  _globals['_DELETEBUILDREQUEST']._serialized_end=2051
  _globals['_DELETEBUILDRESPONSE']._serialized_start=2053
  _globals['_DELETEBUILDRESPONSE']._serialized_end=2074
  _globals['_GETTAGPATHREQUEST']._serialized_start=2076
  _globals['_GETTAGPATHREQUEST']._serialized_end=2173
  _globals['_GETTAGPATHRESPONSE']._serialized_start=2175
  _globals['_GETTAGPATHRESPONSE']._serialized_end=2213
  _globals['_RERUNBUILDFROMEXISTINGREQUEST']._serialized_start=2216
  _globals['_RERUNBUILDFROMEXISTINGREQUEST']._serialized_end=2508
  _globals['_RERUNBUILDFROMEXISTINGRESPONSE']._serialized_start=2510
  _globals['_RERUNBUILDFROMEXISTINGRESPONSE']._serialized_end=2542
  _globals['_GETBUILDSARTIFACTSSCANSUMMARYREQUEST']._serialized_start=2544
  _globals['_GETBUILDSARTIFACTSSCANSUMMARYREQUEST']._serialized_end=2627
  _globals['_GETBUILDSARTIFACTSSCANSUMMARYRESPONSE']._serialized_start=2630
  _globals['_GETBUILDSARTIFACTSSCANSUMMARYRESPONSE']._serialized_end=2971
  _globals['_GETBUILDSARTIFACTSSCANSUMMARYRESPONSE_RESULTBYARTIFACTNAMEENTRY']._serialized_start=2874
  _globals['_GETBUILDSARTIFACTSSCANSUMMARYRESPONSE_RESULTBYARTIFACTNAMEENTRY']._serialized_end=2971
  _globals['_GETBUILDIMAGEDETAILSREQUEST']._serialized_start=2973
  _globals['_GETBUILDIMAGEDETAILSREQUEST']._serialized_end=3044
  _globals['_GETBUILDIMAGEDETAILSRESPONSE']._serialized_start=3046
  _globals['_GETBUILDIMAGEDETAILSRESPONSE']._serialized_end=3143
  _globals['_UPDATEBUILDNAMEREQUEST']._serialized_start=3145
  _globals['_UPDATEBUILDNAMEREQUEST']._serialized_end=3207
  _globals['_UPDATEBUILDNAMERESPONSE']._serialized_start=3209
  _globals['_UPDATEBUILDNAMERESPONSE']._serialized_end=3234
  _globals['_GETBUILDSARTIFACTSSCANREQUEST']._serialized_start=3236
  _globals['_GETBUILDSARTIFACTSSCANREQUEST']._serialized_end=3348
  _globals['_GETBUILDSARTIFACTSSCANRESPONSE']._serialized_start=3350
  _globals['_GETBUILDSARTIFACTSSCANRESPONSE']._serialized_end=3400
  _globals['_BUILDAPI']._serialized_start=3678
  _globals['_BUILDAPI']._serialized_end=5576
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/audience/v1/audience.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fqwak/audience/v1/audience.proto\x12\x10qwak.audience.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"I\n\rAudienceEntry\x12\n\n\x02id\x18\x01 \x01(\t\x12,\n\x08\x61udience\x18\x02 \x01(\x0b\x32\x1a.qwak.audience.v1.Audience\"\xc1\x03\n\x08\x41udience\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12/\n\nconditions\x18\x03 \x03(\x0b\x32\x1b.qwak.audience.v1.Condition\x12\'\n\x06routes\x18\x04 \x03(\x0b\x32\x17.qwak.audience.v1.Route\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12,\n\x08modified\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bmodified_by\x18\x08 \x01(\t\x12M\n\x12\x65nvironment_routes\x18\t \x03(\x0b\x32\x31.qwak.audience.v1.Audience.EnvironmentRoutesEntry\x1a\x65\n\x16\x45nvironmentRoutesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.qwak.audience.v1.EnvironmentAudienceRoutes:\x02\x38\x01\"D\n\x19\x45nvironmentAudienceRoutes\x12\'\n\x06routes\x18\x01 \x03(\x0b\x32\x17.qwak.audience.v1.Route\"y\n\x13\x41udienceRoutesEntry\x12\x13\n\x0b\x61udience_id\x18\x01 \x01(\t\x12\x15\n\raudience_name\x18\x02 \x01(\t\x12\'\n\x06routes\x18\x04 \x03(\x0b\x32\x17.qwak.audience.v1.Route\x12\r\n\x05order\x18\x05 \x01(\x05\"\xb1\x01\n\tCondition\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x10\x62inary_condition\x18\x02 \x01(\x0b\x32!.qwak.audience.v1.BinaryConditionH\x00\x12;\n\x0funary_condition\x18\x03 \x01(\x0b\x32 .qwak.audience.v1.UnaryConditionH\x00\x12\x0e\n\x06invert\x18\x04 \x01(\x08\x42\x0b\n\tcondition\"X\n\x0eUnaryCondition\x12\x35\n\x08operator\x18\x01 \x01(\x0e\x32#.qwak.audience.v1.UnaryOperatorType\x12\x0f\n\x07operand\x18\x02 \x01(\t\"x\n\x0f\x42inaryCondition\x12\x36\n\x08operator\x18\x01 \x01(\x0e\x32$.qwak.audience.v1.BinaryOperatorType\x12\x15\n\rfirst_operand\x18\x02 \x01(\t\x12\x16\n\x0esecond_operand\x18\x03 \x01(\t\"\x9a\x01\n\x05Route\x12\x16\n\x0evariation_name\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\r\x12\x0e\n\x06shadow\x18\x03 \x01(\x08\x12\x10\n\x08model_id\x18\x04 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\x12\x13\n\x0b\x61udience_id\x18\x06 \x01(\t\x12\x1a\n\x12request_timeout_ms\x18\x07 \x01(\x05*\x9e\x02\n\x11UnaryOperatorType\x12\x1f\n\x1bUNARY_OPERATOR_TYPE_INVALID\x10\x00\x12#\n\x1fUNARY_OPERATOR_TYPE_EXACT_MATCH\x10\x01\x12(\n$UNARY_OPERATOR_TYPE_SAFE_REGEX_MATCH\x10\x02\x12%\n!UNARY_OPERATOR_TYPE_PRESENT_MATCH\x10\x03\x12$\n UNARY_OPERATOR_TYPE_PREFIX_MATCH\x10\x04\x12$\n UNARY_OPERATOR_TYPE_SUFFIX_MATCH\x10\x05\x12&\n\"UNARY_OPERATOR_TYPE_CONTAINS_MATCH\x10\x06*\\\n\x12\x42inaryOperatorType\x12 \n\x1c\x42INARY_OPERATOR_TYPE_INVALID\x10\x00\x12$\n BINARY_OPERATOR_TYPE_RANGE_MATCH\x10\x01\x42\x42\n\x14\x63om.qwak.audience.v1B\rAudienceProtoP\x01Z\x19qwak/audience/v1;audienceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.audience.v1.audience_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.qwak.audience.v1B\rAudienceProtoP\001Z\031qwak/audience/v1;audience'
  _AUDIENCE_ENVIRONMENTROUTESENTRY._options = None
  _AUDIENCE_ENVIRONMENTROUTESENTRY._serialized_options = b'8\001'
  _globals['_UNARYOPERATORTYPE']._serialized_start=1356
  _globals['_UNARYOPERATORTYPE']._serialized_end=1642
  _globals['_BINARYOPERATORTYPE']._serialized_start=1644
  _globals['_BINARYOPERATORTYPE']._serialized_end=1736
  _globals['_AUDIENCEENTRY']._serialized_start=86
  _globals['_AUDIENCEENTRY']._serialized_end=159
  _globals['_AUDIENCE']._serialized_start=162
  _globals['_AUDIENCE']._serialized_end=611
  _globals['_AUDIENCE_ENVIRONMENTROUTESENTRY']._serialized_start=510
  _globals['_AUDIENCE_ENVIRONMENTROUTESENTRY']._serialized_end=611
  _globals['_ENVIRONMENTAUDIENCEROUTES']._serialized_start=613
  _globals['_ENVIRONMENTAUDIENCEROUTES']._serialized_end=681
  _globals['_AUDIENCEROUTESENTRY']._serialized_start=683
  _globals['_AUDIENCEROUTESENTRY']._serialized_end=804
  _globals['_CONDITION']._serialized_start=807
  _globals['_CONDITION']._serialized_end=984
  _globals['_UNARYCONDITION']._serialized_start=986
  _globals['_UNARYCONDITION']._serialized_end=1074
  _globals['_BINARYCONDITION']._serialized_start=1076
  _globals['_BINARYCONDITION']._serialized_end=1196
  _globals['_ROUTE']._serialized_start=1199
  _globals['_ROUTE']._serialized_end=1353
# @@protoc_insertion_point(module_scope)



from abc import ABC, abstractmethod
from typing import Any


class BaseOutputAdapter(ABC):
    @staticmethod
    def http_content_type():
        return {"Content-Type": "text/plain; charset=utf-8"}

    @staticmethod
    @abstractmethod
    def pack_user_func_return_value(return_result: Any) -> Any:
        pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/prompt/v1/prompt/prompt.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.model_descriptor import open_ai_descriptor_pb2 as qwak_dot_model__descriptor_dot_open__ai__descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"qwak/prompt/v1/prompt/prompt.proto\x12\x15qwak.prompt.v1.prompt\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.qwak/model_descriptor/open_ai_descriptor.proto\"\xdb\x01\n\x06Prompt\x12\x0c\n\x04name\x18\x01 \x01(\t\x12R\n\x1a\x64\x65\x66\x61ult_version_definition\x18\x02 \x01(\x0b\x32..qwak.prompt.v1.prompt.PromptVersionDefinition\x12\x37\n\x08metadata\x18\x03 \x01(\x0b\x32%.qwak.prompt.v1.prompt.PromptMetadata\x12\x36\n\x0bprompt_spec\x18\x04 \x01(\x0b\x32!.qwak.prompt.v1.prompt.PromptSpec\"w\n\rPromptVersion\x12\x13\n\x0bprompt_name\x18\x01 \x01(\t\x12Q\n\x19prompt_version_definition\x18\x02 \x01(\x0b\x32..qwak.prompt.v1.prompt.PromptVersionDefinition\"\xb9\x01\n\x17PromptVersionDefinition\x12\x16\n\x0eversion_number\x18\x01 \x01(\x05\x12>\n\x0cversion_spec\x18\x02 \x01(\x0b\x32(.qwak.prompt.v1.prompt.PromptVersionSpec\x12\x46\n\x10version_metadata\x18\x03 \x01(\x0b\x32,.qwak.prompt.v1.prompt.PromptVersionMetadata\"^\n\x0bPromptBrief\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x41\n\x0eversion_briefs\x18\x02 \x03(\x0b\x32).qwak.prompt.v1.prompt.PromptVersionBrief\"\x98\x01\n\x12PromptVersionBrief\x12\x16\n\x0eversion_number\x18\x01 \x01(\x05\x12I\n\x14model_provider_brief\x18\x02 \x01(\x0b\x32).qwak.prompt.v1.prompt.ModelProviderBriefH\x00\x42\x1f\n\x1doptional_model_provider_brief\"8\n\x12ModelProviderBrief\x12\"\n\x1amodel_provider_case_number\x18\x01 \x01(\x05\"!\n\nPromptSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\"\xcf\x01\n\x11PromptVersionSpec\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12>\n\x0fprompt_template\x18\x02 \x01(\x0b\x32%.qwak.prompt.v1.prompt.PromptTemplate\x12H\n\x10model_descriptor\x18\x03 \x01(\x0b\x32,.qwak.prompt.v1.prompt.PromptModelDescriptorH\x00\x42\x1b\n\x19optional_model_descriptor\"c\n\x0ePromptTemplate\x12I\n\x14\x63hat_prompt_template\x18\x01 \x01(\x0b\x32).qwak.prompt.v1.prompt.ChatPromptTemplateH\x00\x42\x06\n\x04type\"O\n\x12\x43hatPromptTemplate\x12\x39\n\rchat_messages\x18\x01 \x03(\x0b\x32\".qwak.prompt.v1.prompt.ChatMessage\"\x83\x01\n\x0b\x43hatMessage\x12\x36\n\x04role\x18\x01 \x01(\x0b\x32(.qwak.prompt.v1.prompt.PromptMessageRole\x12<\n\x08template\x18\x02 \x01(\x0b\x32*.qwak.prompt.v1.prompt.ChatMessageTemplate\"[\n\x13\x43hatMessageTemplate\x12<\n\rtext_template\x18\x01 \x01(\x0b\x32#.qwak.prompt.v1.prompt.TextTemplateH\x00\x42\x06\n\x04type\" \n\x0cTextTemplate\x12\x10\n\x08template\x18\x01 \x01(\t\"\xe6\x01\n\x11PromptMessageRole\x12\x43\n\nhuman_role\x18\x01 \x01(\x0b\x32-.qwak.prompt.v1.prompt.HumanPromptMessageRoleH\x00\x12\x45\n\x0bsystem_role\x18\x02 \x01(\x0b\x32..qwak.prompt.v1.prompt.SystemPromptMessageRoleH\x00\x12=\n\x07\x61i_role\x18\x03 \x01(\x0b\x32*.qwak.prompt.v1.prompt.AIPromptMessageRoleH\x00\x42\x06\n\x04role\"\x18\n\x16HumanPromptMessageRole\"\x19\n\x17SystemPromptMessageRole\"\x15\n\x13\x41IPromptMessageRole\"r\n\x15PromptModelDescriptor\x12G\n\x10open_ai_provider\x18\x01 \x01(\x0b\x32+.qwak.prompt.v1.prompt.PromptOpenAIProviderH\x00\x42\x10\n\x0emodel_provider\"t\n\x14PromptOpenAIProvider\x12\\\n\x18open_ai_model_descriptor\x18\x01 \x01(\x0b\x32:.qwak.llmops.model_descriptor.openai.OpenAIModelDescriptor\"T\n\x0ePromptMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\"[\n\x15PromptVersionMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\tB$\n com.qwak.ai.prompt.api.v1.promptP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.prompt.v1.prompt.prompt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.qwak.ai.prompt.api.v1.promptP\001'
  _globals['_PROMPT']._serialized_start=143
  _globals['_PROMPT']._serialized_end=362
  _globals['_PROMPTVERSION']._serialized_start=364
  _globals['_PROMPTVERSION']._serialized_end=483
  _globals['_PROMPTVERSIONDEFINITION']._serialized_start=486
  _globals['_PROMPTVERSIONDEFINITION']._serialized_end=671
  _globals['_PROMPTBRIEF']._serialized_start=673
  _globals['_PROMPTBRIEF']._serialized_end=767
  _globals['_PROMPTVERSIONBRIEF']._serialized_start=770
  _globals['_PROMPTVERSIONBRIEF']._serialized_end=922
  _globals['_MODELPROVIDERBRIEF']._serialized_start=924
  _globals['_MODELPROVIDERBRIEF']._serialized_end=980
  _globals['_PROMPTSPEC']._serialized_start=982
  _globals['_PROMPTSPEC']._serialized_end=1015
  _globals['_PROMPTVERSIONSPEC']._serialized_start=1018
  _globals['_PROMPTVERSIONSPEC']._serialized_end=1225
  _globals['_PROMPTTEMPLATE']._serialized_start=1227
  _globals['_PROMPTTEMPLATE']._serialized_end=1326
  _globals['_CHATPROMPTTEMPLATE']._serialized_start=1328
  _globals['_CHATPROMPTTEMPLATE']._serialized_end=1407
  _globals['_CHATMESSAGE']._serialized_start=1410
  _globals['_CHATMESSAGE']._serialized_end=1541
  _globals['_CHATMESSAGETEMPLATE']._serialized_start=1543
  _globals['_CHATMESSAGETEMPLATE']._serialized_end=1634
  _globals['_TEXTTEMPLATE']._serialized_start=1636
  _globals['_TEXTTEMPLATE']._serialized_end=1668
  _globals['_PROMPTMESSAGEROLE']._serialized_start=1671
  _globals['_PROMPTMESSAGEROLE']._serialized_end=1901
  _globals['_HUMANPROMPTMESSAGEROLE']._serialized_start=1903
  _globals['_HUMANPROMPTMESSAGEROLE']._serialized_end=1927
  _globals['_SYSTEMPROMPTMESSAGEROLE']._serialized_start=1929
  _globals['_SYSTEMPROMPTMESSAGEROLE']._serialized_end=1954
  _globals['_AIPROMPTMESSAGEROLE']._serialized_start=1956
  _globals['_AIPROMPTMESSAGEROLE']._serialized_end=1977
  _globals['_PROMPTMODELDESCRIPTOR']._serialized_start=1979
  _globals['_PROMPTMODELDESCRIPTOR']._serialized_end=2093
  _globals['_PROMPTOPENAIPROVIDER']._serialized_start=2095
  _globals['_PROMPTOPENAIPROVIDER']._serialized_end=2211
  _globals['_PROMPTMETADATA']._serialized_start=2213
  _globals['_PROMPTMETADATA']._serialized_end=2297
  _globals['_PROMPTVERSIONMETADATA']._serialized_start=2299
  _globals['_PROMPTVERSIONMETADATA']._serialized_end=2390
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class UserSecretSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.str
    """Base64 encoded Value of the secret"""
    def __init__(
        self,
        *,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___UserSecretSpec = UserSecretSpec

class SystemSecretSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    @property
    def value(self) -> global___SystemSecretValue:
        """The Value of The Secret"""
    def __init__(
        self,
        *,
        value: global___SystemSecretValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___SystemSecretSpec = SystemSecretSpec

class SystemSecretDefinition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> global___EnvironmentSecretIdentifier:
        """Secret identifier"""
    @property
    def spec(self) -> global___SystemSecretSpec:
        """Secret Spec"""
    def __init__(
        self,
        *,
        identifier: global___EnvironmentSecretIdentifier | None = ...,
        spec: global___SystemSecretSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "spec", b"spec"]) -> None: ...

global___SystemSecretDefinition = SystemSecretDefinition

class EnvironmentSecretIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the secret"""
    environment_id: builtins.str
    """Environment of secret"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "name", b"name"]) -> None: ...

global___EnvironmentSecretIdentifier = EnvironmentSecretIdentifier

class SetUserEnvironmentSecretOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> global___EnvironmentSecretIdentifier:
        """Secret identifier"""
    @property
    def spec(self) -> global___UserSecretSpec:
        """Secret Spec"""
    def __init__(
        self,
        *,
        identifier: global___EnvironmentSecretIdentifier | None = ...,
        spec: global___UserSecretSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "spec", b"spec"]) -> None: ...

global___SetUserEnvironmentSecretOptions = SetUserEnvironmentSecretOptions

class SetSystemEnvironmentSecretOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> global___EnvironmentSecretIdentifier:
        """Secret identifier"""
    @property
    def spec(self) -> global___SystemSecretSpec:
        """Secret Spec"""
    def __init__(
        self,
        *,
        identifier: global___EnvironmentSecretIdentifier | None = ...,
        spec: global___SystemSecretSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier", b"identifier", "spec", b"spec"]) -> None: ...

global___SetSystemEnvironmentSecretOptions = SetSystemEnvironmentSecretOptions

class SystemSecretValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPAQUE_FIELD_NUMBER: builtins.int
    DOCKER_CONFIG_JSON_FIELD_NUMBER: builtins.int
    OPAQUE_PAIR_FIELD_NUMBER: builtins.int
    opaque: builtins.str
    """Base64 encoded value"""
    @property
    def docker_config_json(self) -> google.protobuf.struct_pb2.Struct:
        """Serialized ~/.docker/config.json file"""
    @property
    def opaque_pair(self) -> global___OpaquePairValue:
        """map of pairs arbitrary user-defined data"""
    def __init__(
        self,
        *,
        opaque: builtins.str = ...,
        docker_config_json: google.protobuf.struct_pb2.Struct | None = ...,
        opaque_pair: global___OpaquePairValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["docker_config_json", b"docker_config_json", "opaque", b"opaque", "opaque_pair", b"opaque_pair", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["docker_config_json", b"docker_config_json", "opaque", b"opaque", "opaque_pair", b"opaque_pair", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["value", b"value"]) -> typing_extensions.Literal["opaque", "docker_config_json", "opaque_pair"] | None: ...

global___SystemSecretValue = SystemSecretValue

class OpaquePairValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class PairsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PAIRS_FIELD_NUMBER: builtins.int
    @property
    def pairs(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """key and Base64 encoded value"""
    def __init__(
        self,
        *,
        pairs: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pairs", b"pairs"]) -> None: ...

global___OpaquePairValue = OpaquePairValue

class AccountSecrets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRETS_FIELD_NUMBER: builtins.int
    @property
    def secrets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvironmentSecretMetadata]:
        """Environment secrets"""
    def __init__(
        self,
        *,
        secrets: collections.abc.Iterable[global___EnvironmentSecretMetadata] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secrets", b"secrets"]) -> None: ...

global___AccountSecrets = AccountSecrets

class EnvironmentSecretMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LAST_UPDATED_AT_FIELD_NUMBER: builtins.int
    @property
    def identifier(self) -> global___EnvironmentSecretIdentifier:
        """Secret Identifier"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Created at datetime"""
    @property
    def last_updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last updated at datetime"""
    def __init__(
        self,
        *,
        identifier: global___EnvironmentSecretIdentifier | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "identifier", b"identifier", "last_updated_at", b"last_updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "identifier", b"identifier", "last_updated_at", b"last_updated_at"]) -> None: ...

global___EnvironmentSecretMetadata = EnvironmentSecretMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.creds.secret_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class BasicAuth(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def username(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    @property
    def password(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    def __init__(
        self,
        *,
        username: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
        password: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["password", b"password", "username", b"username"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "username", b"username"]) -> None: ...

global___BasicAuth = BasicAuth



from abc import ABC, abstractmethod
from dataclasses import dataclass
from typing import Optional

from _qwak_proto.qwak.monitoring.v0.alerting_channel_pb2 import (
    AlertingChannelDescription,
    AlertingChannelMetadata,
    AlertingChannelSpec,
)
from _qwak_proto.qwak.monitoring.v0.alerting_channel_pb2 import (
    ChannelConfiguration as ChannelConfigurationProto,
)
from _qwak_proto.qwak.monitoring.v0.alerting_channel_pb2 import (
    OpsgenieType,
    PagerDutyType,
    SecretStringValue,
    SlackType,
)
from qwak.exceptions import QwakException


@dataclass
class ChannelConfiguration(ABC):
    @abstractmethod
    def to_proto(self) -> "ChannelConfigurationProto":
        pass

    @classmethod
    def from_proto(cls, proto: "ChannelConfigurationProto") -> "ChannelConfiguration":
        channel_type: str = proto.WhichOneof("channel_type")

        if channel_type == "slack":
            return SlackChannel.from_proto(proto=proto.slack)
        if channel_type == "pagerduty":
            return PagerDutyChannel.from_proto(proto=proto.pagerduty)
        if channel_type == "opsgenie":
            return OpsGenieChannel.from_proto(proto=proto.opsgenie)

        raise QwakException(f"Got unsupported channel type: {channel_type}")


@dataclass
class Channel:
    name: str
    channel_conf: ChannelConfiguration

    def __post_init__(self):
        import re

        allowed_pattern = "^[a-z]+[a-z0-9_]*$"
        result = re.match(allowed_pattern, self.name)
        if not result:
            raise QwakException(
                "Channel name is limited to lower case letters and numbers, must start with a letter."
            )

    def to_proto(self) -> AlertingChannelDescription:
        metadata = AlertingChannelMetadata(name=self.name, id="")
        return AlertingChannelDescription(
            metadata=metadata,
            spec=AlertingChannelSpec(configuration=self.channel_conf.to_proto()),
        )

    @classmethod
    def from_proto(cls, proto: "AlertingChannelDescription") -> "Channel":
        channel_conf: ChannelConfiguration = ChannelConfiguration.from_proto(
            proto.spec.configuration
        )
        return cls(
            name=proto.metadata.name,
            channel_conf=channel_conf,
        )


@dataclass
class SlackChannel(ChannelConfiguration):
    api_url: str

    def to_proto(self) -> ChannelConfigurationProto:
        return ChannelConfigurationProto(
            slack=SlackType(api_url=SecretStringValue(value=self.api_url))
        )

    @classmethod
    def from_proto(cls, proto: "SlackType") -> "SlackChannel":
        return cls(api_url=proto.api_url.value)


@dataclass
class PagerDutyChannel(ChannelConfiguration):
    url: str
    routing_key: Optional[str] = None
    service_key: Optional[str] = None

    def __post_init__(self):
        if (not self.routing_key and not self.service_key) or (
            self.routing_key and self.service_key
        ):
            raise QwakException("Routing and service key are mutually exclusive.")

    def to_proto(self) -> ChannelConfigurationProto:
        return ChannelConfigurationProto(
            pagerduty=PagerDutyType(
                routing_key=SecretStringValue(value=self.routing_key),
                service_key=SecretStringValue(value=self.service_key),
                url=self.url,
            )
        )

    @classmethod
    def from_proto(cls, proto: "PagerDutyType") -> "PagerDutyChannel":
        return cls(
            routing_key=proto.routing_key.value,
            service_key=proto.service_key.value,
            url=proto.url,
        )


@dataclass
class OpsGenieChannel(ChannelConfiguration):
    api_key: str

    def to_proto(self) -> ChannelConfigurationProto:
        return ChannelConfigurationProto(
            opsgenie=OpsgenieType(
                api_key=SecretStringValue(value=self.api_key),
            )
        )

    @classmethod
    def from_proto(cls, proto: "OpsgenieType") -> "OpsGenieChannel":
        return cls(api_key=proto.api_key.value)



from functools import wraps

from qwak.exceptions import QwakException
from qwak.feature_store.validations.validation_response import SuccessValidationResponse


def silence_backend_specific_validation_exceptions(*error_messages_to_silence):
    """
    A decorator that catches specific backend validation exceptions and returns a standardized
    validation success response encapsulating the exception details. Used to skip the validation
    process for certain backend exceptions. hopefully will be removed soon after validations will be supported on
    all environment types.

    Parameters:
        *error_messages_to_silence: Variable length argument list
            Messages that, if present in the exception message, should trigger the
            standardized validation success response instead of propagating the exception.

    Returns:
        function
            The wrapped function that will catch specified backend validation exceptions
            and return a standardized validation success response if any of the specified
            error messages are found in the exception message.

    Usage:
    ------
    @silence_backend_specific_validation_exceptions(
        "Validating DataSource is not supported for self-hosted environments",
        "Validating DataSource is not supported for SAAS environments"
    )
    def validate_data_source():
        # Your function implementation

    When 'validate_data_source_blocking' raises a QwakException containing one of the specified error messages,
    it will return a SuccessValidationResponse, including the
    exception's representation in stderr and in the sample as a dataframe with a warning column.
    If the exception message does not contain any of the specified error messages, the exception is raised normally.
    """

    def decorator(func):
        @wraps(func)
        def wrapper(*args, silence_specific_exceptions: bool = True, **kwargs):
            try:
                return func(*args, **kwargs)
            except QwakException as e:
                is_to_silent_error = silence_specific_exceptions and any(
                    error_message in repr(e)
                    for error_message in error_messages_to_silence
                )
                if not is_to_silent_error:
                    raise e

                try:
                    import pandas as pd
                except ImportError as exc:
                    raise QwakException("Missing required Pandas dependency") from exc

                return (
                    SuccessValidationResponse(
                        sample=pd.DataFrame({"errors": [repr(e)]}),
                        features=[],
                        stdout="",
                        stderr=repr(e),
                    ),
                    None,
                )

        return wrapper

    return decorator



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.account.v1.personalization_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AccountPreferences(google.protobuf.message.Message):
    """An account preferences"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERSONALIZATION_FIELD_NUMBER: builtins.int
    @property
    def personalization(self) -> qwak.administration.account.v1.personalization_pb2.AccountPersonalization:
        """Account personalization"""
    def __init__(
        self,
        *,
        personalization: qwak.administration.account.v1.personalization_pb2.AccountPersonalization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["personalization", b"personalization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["personalization", b"personalization"]) -> None: ...

global___AccountPreferences = AccountPreferences



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/builds_orchestrator_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.builds import build_pb2 as qwak_dot_builds_dot_build__pb2
from _qwak_proto.qwak.builds import build_url_pb2 as qwak_dot_builds_dot_build__url__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-qwak/builds/builds_orchestrator_service.proto\x12\x18qwak.builds.orchestrator\x1a\x17qwak/builds/build.proto\x1a\x1bqwak/builds/build_url.proto\"R\n\x11\x42uildModelRequest\x12=\n\nbuild_spec\x18\x01 \x01(\x0b\x32).qwak.builds.orchestrator.RemoteBuildSpec\"\x14\n\x12\x42uildModelResponse\"+\n\x17\x43\x61ncelBuildModelRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"\x1a\n\x18\x43\x61ncelBuildModelResponse\"*\n\x16\x43reateUploadURLRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"C\n\x17\x43reateUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t\x12\x14\n\x0c\x64ownload_url\x18\x02 \x01(\t\"h\n\"GetBuildVersioningUploadURLRequest\x12\x42\n\x06params\x18\x01 \x01(\x0b\x32\x32.qwak.builds.orchestrator.BuildVersioningUrlParams\"i\n#GetBuildVersioningUploadUrlsRequest\x12\x42\n\x06params\x18\x01 \x03(\x0b\x32\x32.qwak.builds.orchestrator.BuildVersioningUrlParams\"\xa7\x02\n#GetBuildVersioningUploadURLResponse\x12\x12\n\nupload_url\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12Q\n\x15\x61uthentication_detail\x18\x03 \x01(\x0b\x32..qwak.builds.orchestrator.AuthenticationDetailB\x02\x18\x01\x12[\n\x07headers\x18\x04 \x03(\x0b\x32J.qwak.builds.orchestrator.GetBuildVersioningUploadURLResponse.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x14\x41uthenticationDetail\x12Z\n\x1bjfrog_authentication_detail\x18\x01 \x01(\x0b\x32\x33.qwak.builds.orchestrator.JfrogAuthenticationDetailH\x00\x42\x12\n\x10integration_type\"\xf4\x01\n$GetBuildVersioningUploadUrlsResponse\x12l\n\x10upload_url_infos\x18\x01 \x03(\x0b\x32R.qwak.builds.orchestrator.GetBuildVersioningUploadUrlsResponse.UploadUrlInfosEntry\x1a^\n\x13UploadUrlInfosEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.qwak.builds.orchestrator.UploadUrlInfo:\x02\x38\x01\"\xa8\x01\n\rUploadUrlInfo\x12\x12\n\nupload_url\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x45\n\x07headers\x18\x03 \x03(\x0b\x32\x34.qwak.builds.orchestrator.UploadUrlInfo.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x19JfrogAuthenticationDetail\x12\x10\n\x08username\x18\x01 \x01(\t\x12\r\n\x05token\x18\x02 \x01(\t\"j\n$GetBuildVersioningDownloadURLRequest\x12\x42\n\x06params\x18\x01 \x01(\x0b\x32\x32.qwak.builds.orchestrator.BuildVersioningUrlParams\"k\n%GetBuildVersioningDownloadUrLsRequest\x12\x42\n\x06params\x18\x01 \x03(\x0b\x32\x32.qwak.builds.orchestrator.BuildVersioningUrlParams\"\xdf\x01\n%GetBuildVersioningDownloadURLResponse\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\x12\x11\n\tfile_size\x18\x02 \x01(\x03\x12]\n\x07headers\x18\x03 \x03(\x0b\x32L.qwak.builds.orchestrator.GetBuildVersioningDownloadURLResponse.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x02\n&GetBuildVersioningDownloadUrlsResponse\x12r\n\x12\x64ownload_url_infos\x18\x01 \x03(\x0b\x32V.qwak.builds.orchestrator.GetBuildVersioningDownloadUrlsResponse.DownloadUrlInfosEntry\x1a\x62\n\x15\x44ownloadUrlInfosEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).qwak.builds.orchestrator.DownloadUrlInfo:\x02\x38\x01\"\xb3\x01\n\x0f\x44ownloadUrlInfo\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\x12\x11\n\tfile_size\x18\x02 \x01(\x03\x12G\n\x07headers\x18\x03 \x03(\x0b\x32\x36.qwak.builds.orchestrator.DownloadUrlInfo.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x1eListBuildVersioningTagsRequest\x12L\n\x15\x62uild_versioning_tags\x18\x01 \x01(\x0b\x32-.qwak.builds.orchestrator.BuildVersioningTags\"\x9c\x01\n\x1fListBuildVersioningTagsResponse\x12\x61\n build_versioning_tags_properties\x18\x01 \x03(\x0b\x32\x37.qwak.builds.orchestrator.BuildVersioningTagsProperties\x12\x16\n\x0eui_direct_link\x18\x02 \x01(\t\"\x95\x01\n\x16\x43reateDataTableRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12<\n\x05table\x18\x04 \x01(\x0b\x32-.qwak.builds.orchestrator.DataTableDefinition\x12\x0c\n\x04path\x18\x05 \x01(\t\"\x19\n\x17\x43reateDataTableResponse\"n\n\x1dGetBaseDockerImageNameRequest\x12M\n\x16\x62\x61se_docker_image_type\x18\x01 \x01(\x0e\x32-.qwak.builds.orchestrator.BaseDockerImageType\"@\n\x1eGetBaseDockerImageNameResponse\x12\x1e\n\x16\x62\x61se_docker_image_name\x18\x01 \x01(\t\"f\n\x17SaveArtifactPathRequest\x12K\n\x12\x61rtifact_path_spec\x18\x01 \x01(\x0b\x32/.qwak.builds.orchestrator.BuildArtifactPathSpec\"\x1a\n\x18SaveArtifactPathResponse\"-\n\x19ListBuildArtifactsRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"X\n\x1aListBuildArtifactsResponse\x12:\n\tartifacts\x18\x01 \x03(\x0b\x32\'.qwak.builds.orchestrator.BuildArtifact\"A\n$DetachBuildsFromModelVersionsRequest\x12\x19\n\x11model_version_ids\x18\x01 \x03(\t\"\'\n%DetachBuildsFromModelVersionsResponse2\xb8\x0e\n\x19\x42uildsOrchestratorService\x12g\n\nBuildModel\x12+.qwak.builds.orchestrator.BuildModelRequest\x1a,.qwak.builds.orchestrator.BuildModelResponse\x12y\n\x10\x43\x61ncelBuildModel\x12\x31.qwak.builds.orchestrator.CancelBuildModelRequest\x1a\x32.qwak.builds.orchestrator.CancelBuildModelResponse\x12{\n\x0f\x43reateUploadURL\x12\x30.qwak.builds.orchestrator.CreateUploadURLRequest\x1a\x31.qwak.builds.orchestrator.CreateUploadURLResponse\"\x03\x88\x02\x01\x12\x9a\x01\n\x1bGetBuildVersioningUploadURL\x12<.qwak.builds.orchestrator.GetBuildVersioningUploadURLRequest\x1a=.qwak.builds.orchestrator.GetBuildVersioningUploadURLResponse\x12\x9d\x01\n\x1cGetBuildVersioningUploadUrls\x12=.qwak.builds.orchestrator.GetBuildVersioningUploadUrlsRequest\x1a>.qwak.builds.orchestrator.GetBuildVersioningUploadUrlsResponse\x12\xa0\x01\n\x1dGetBuildVersioningDownloadURL\x12>.qwak.builds.orchestrator.GetBuildVersioningDownloadURLRequest\x1a?.qwak.builds.orchestrator.GetBuildVersioningDownloadURLResponse\x12\xa3\x01\n\x1eGetBuildVersioningDownloadUrls\x12?.qwak.builds.orchestrator.GetBuildVersioningDownloadUrLsRequest\x1a@.qwak.builds.orchestrator.GetBuildVersioningDownloadUrlsResponse\x12\x8e\x01\n\x17ListBuildVersioningTags\x12\x38.qwak.builds.orchestrator.ListBuildVersioningTagsRequest\x1a\x39.qwak.builds.orchestrator.ListBuildVersioningTagsResponse\x12v\n\x0f\x43reateDataTable\x12\x30.qwak.builds.orchestrator.CreateDataTableRequest\x1a\x31.qwak.builds.orchestrator.CreateDataTableResponse\x12\x8b\x01\n\x16GetBaseDockerImageName\x12\x37.qwak.builds.orchestrator.GetBaseDockerImageNameRequest\x1a\x38.qwak.builds.orchestrator.GetBaseDockerImageNameResponse\x12y\n\x10SaveArtifactPath\x12\x31.qwak.builds.orchestrator.SaveArtifactPathRequest\x1a\x32.qwak.builds.orchestrator.SaveArtifactPathResponse\x12\x7f\n\x12ListBuildArtifacts\x12\x33.qwak.builds.orchestrator.ListBuildArtifactsRequest\x1a\x34.qwak.builds.orchestrator.ListBuildArtifactsResponse\x12\xa0\x01\n\x1d\x44\x65tachBuildsFromModelVersions\x12>.qwak.builds.orchestrator.DetachBuildsFromModelVersionsRequest\x1a?.qwak.builds.orchestrator.DetachBuildsFromModelVersionsResponseB\'\n#com.qwak.ai.builds.orchestrator.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.builds.builds_orchestrator_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.builds.orchestrator.apiP\001'
  _GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY._options = None
  _GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY._serialized_options = b'8\001'
  _GETBUILDVERSIONINGUPLOADURLRESPONSE.fields_by_name['authentication_detail']._options = None
  _GETBUILDVERSIONINGUPLOADURLRESPONSE.fields_by_name['authentication_detail']._serialized_options = b'\030\001'
  _GETBUILDVERSIONINGUPLOADURLSRESPONSE_UPLOADURLINFOSENTRY._options = None
  _GETBUILDVERSIONINGUPLOADURLSRESPONSE_UPLOADURLINFOSENTRY._serialized_options = b'8\001'
  _UPLOADURLINFO_HEADERSENTRY._options = None
  _UPLOADURLINFO_HEADERSENTRY._serialized_options = b'8\001'
  _GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY._options = None
  _GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY._serialized_options = b'8\001'
  _GETBUILDVERSIONINGDOWNLOADURLSRESPONSE_DOWNLOADURLINFOSENTRY._options = None
  _GETBUILDVERSIONINGDOWNLOADURLSRESPONSE_DOWNLOADURLINFOSENTRY._serialized_options = b'8\001'
  _DOWNLOADURLINFO_HEADERSENTRY._options = None
  _DOWNLOADURLINFO_HEADERSENTRY._serialized_options = b'8\001'
  _BUILDSORCHESTRATORSERVICE.methods_by_name['CreateUploadURL']._options = None
  _BUILDSORCHESTRATORSERVICE.methods_by_name['CreateUploadURL']._serialized_options = b'\210\002\001'
  _globals['_BUILDMODELREQUEST']._serialized_start=129
  _globals['_BUILDMODELREQUEST']._serialized_end=211
  _globals['_BUILDMODELRESPONSE']._serialized_start=213
  _globals['_BUILDMODELRESPONSE']._serialized_end=233
  _globals['_CANCELBUILDMODELREQUEST']._serialized_start=235
  _globals['_CANCELBUILDMODELREQUEST']._serialized_end=278
  _globals['_CANCELBUILDMODELRESPONSE']._serialized_start=280
  _globals['_CANCELBUILDMODELRESPONSE']._serialized_end=306
  _globals['_CREATEUPLOADURLREQUEST']._serialized_start=308
  _globals['_CREATEUPLOADURLREQUEST']._serialized_end=350
  _globals['_CREATEUPLOADURLRESPONSE']._serialized_start=352
  _globals['_CREATEUPLOADURLRESPONSE']._serialized_end=419
  _globals['_GETBUILDVERSIONINGUPLOADURLREQUEST']._serialized_start=421
  _globals['_GETBUILDVERSIONINGUPLOADURLREQUEST']._serialized_end=525
  _globals['_GETBUILDVERSIONINGUPLOADURLSREQUEST']._serialized_start=527
  _globals['_GETBUILDVERSIONINGUPLOADURLSREQUEST']._serialized_end=632
  _globals['_GETBUILDVERSIONINGUPLOADURLRESPONSE']._serialized_start=635
  _globals['_GETBUILDVERSIONINGUPLOADURLRESPONSE']._serialized_end=930
  _globals['_GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY']._serialized_start=884
  _globals['_GETBUILDVERSIONINGUPLOADURLRESPONSE_HEADERSENTRY']._serialized_end=930
  _globals['_AUTHENTICATIONDETAIL']._serialized_start=933
  _globals['_AUTHENTICATIONDETAIL']._serialized_end=1067
  _globals['_GETBUILDVERSIONINGUPLOADURLSRESPONSE']._serialized_start=1070
  _globals['_GETBUILDVERSIONINGUPLOADURLSRESPONSE']._serialized_end=1314
  _globals['_GETBUILDVERSIONINGUPLOADURLSRESPONSE_UPLOADURLINFOSENTRY']._serialized_start=1220
  _globals['_GETBUILDVERSIONINGUPLOADURLSRESPONSE_UPLOADURLINFOSENTRY']._serialized_end=1314
  _globals['_UPLOADURLINFO']._serialized_start=1317
  _globals['_UPLOADURLINFO']._serialized_end=1485
  _globals['_UPLOADURLINFO_HEADERSENTRY']._serialized_start=884
  _globals['_UPLOADURLINFO_HEADERSENTRY']._serialized_end=930
  _globals['_JFROGAUTHENTICATIONDETAIL']._serialized_start=1487
  _globals['_JFROGAUTHENTICATIONDETAIL']._serialized_end=1547
  _globals['_GETBUILDVERSIONINGDOWNLOADURLREQUEST']._serialized_start=1549
  _globals['_GETBUILDVERSIONINGDOWNLOADURLREQUEST']._serialized_end=1655
  _globals['_GETBUILDVERSIONINGDOWNLOADURLSREQUEST']._serialized_start=1657
  _globals['_GETBUILDVERSIONINGDOWNLOADURLSREQUEST']._serialized_end=1764
  _globals['_GETBUILDVERSIONINGDOWNLOADURLRESPONSE']._serialized_start=1767
  _globals['_GETBUILDVERSIONINGDOWNLOADURLRESPONSE']._serialized_end=1990
  _globals['_GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY']._serialized_start=884
  _globals['_GETBUILDVERSIONINGDOWNLOADURLRESPONSE_HEADERSENTRY']._serialized_end=930
  _globals['_GETBUILDVERSIONINGDOWNLOADURLSRESPONSE']._serialized_start=1993
  _globals['_GETBUILDVERSIONINGDOWNLOADURLSRESPONSE']._serialized_end=2249
  _globals['_GETBUILDVERSIONINGDOWNLOADURLSRESPONSE_DOWNLOADURLINFOSENTRY']._serialized_start=2151
  _globals['_GETBUILDVERSIONINGDOWNLOADURLSRESPONSE_DOWNLOADURLINFOSENTRY']._serialized_end=2249
  _globals['_DOWNLOADURLINFO']._serialized_start=2252
  _globals['_DOWNLOADURLINFO']._serialized_end=2431
  _globals['_DOWNLOADURLINFO_HEADERSENTRY']._serialized_start=884
  _globals['_DOWNLOADURLINFO_HEADERSENTRY']._serialized_end=930
  _globals['_LISTBUILDVERSIONINGTAGSREQUEST']._serialized_start=2433
  _globals['_LISTBUILDVERSIONINGTAGSREQUEST']._serialized_end=2543
  _globals['_LISTBUILDVERSIONINGTAGSRESPONSE']._serialized_start=2546
  _globals['_LISTBUILDVERSIONINGTAGSRESPONSE']._serialized_end=2702
  _globals['_CREATEDATATABLEREQUEST']._serialized_start=2705
  _globals['_CREATEDATATABLEREQUEST']._serialized_end=2854
  _globals['_CREATEDATATABLERESPONSE']._serialized_start=2856
  _globals['_CREATEDATATABLERESPONSE']._serialized_end=2881
  _globals['_GETBASEDOCKERIMAGENAMEREQUEST']._serialized_start=2883
  _globals['_GETBASEDOCKERIMAGENAMEREQUEST']._serialized_end=2993
  _globals['_GETBASEDOCKERIMAGENAMERESPONSE']._serialized_start=2995
  _globals['_GETBASEDOCKERIMAGENAMERESPONSE']._serialized_end=3059
  _globals['_SAVEARTIFACTPATHREQUEST']._serialized_start=3061
  _globals['_SAVEARTIFACTPATHREQUEST']._serialized_end=3163
  _globals['_SAVEARTIFACTPATHRESPONSE']._serialized_start=3165
  _globals['_SAVEARTIFACTPATHRESPONSE']._serialized_end=3191
  _globals['_LISTBUILDARTIFACTSREQUEST']._serialized_start=3193
  _globals['_LISTBUILDARTIFACTSREQUEST']._serialized_end=3238
  _globals['_LISTBUILDARTIFACTSRESPONSE']._serialized_start=3240
  _globals['_LISTBUILDARTIFACTSRESPONSE']._serialized_end=3328
  _globals['_DETACHBUILDSFROMMODELVERSIONSREQUEST']._serialized_start=3330
  _globals['_DETACHBUILDSFROMMODELVERSIONSREQUEST']._serialized_end=3395
  _globals['_DETACHBUILDSFROMMODELVERSIONSRESPONSE']._serialized_start=3397
  _globals['_DETACHBUILDSFROMMODELVERSIONSRESPONSE']._serialized_end=3436
  _globals['_BUILDSORCHESTRATORSERVICE']._serialized_start=3439
  _globals['_BUILDSORCHESTRATORSERVICE']._serialized_end=5287
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.execution.v1 import execution_service_pb2 as qwak_dot_execution_dot_v1_dot_execution__service__pb2


class FeatureStoreExecutionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TriggerBatchBackfill = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerBatchBackfill',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBackfillRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBackfillResponse.FromString,
                )
        self.TriggerBatchFeatureset = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerBatchFeatureset',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBatchFeaturesetRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBatchFeaturesetResponse.FromString,
                )
        self.TriggerOnlineStreamingIngestion = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerOnlineStreamingIngestion',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOnlineStreamingIngestionRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOnlineStreamingIngestionResponse.FromString,
                )
        self.TriggerOfflineStreamingIngestion = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerOfflineStreamingIngestion',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOfflineStreamingIngestionRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOfflineStreamingIngestionResponse.FromString,
                )
        self.TriggerRowLevelStreamingAggregationIngestion = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerRowLevelStreamingAggregationIngestion',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerRowLevelStreamingAggregationIngestionRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerRowLevelStreamingAggregationIngestionResponse.FromString,
                )
        self.TriggerCompactionStreamingAggregationIngestion = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerCompactionStreamingAggregationIngestion',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerCompactionStreamingAggregationIngestionRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerCompactionStreamingAggregationIngestionResponse.FromString,
                )
        self.TriggerStreamingAggregationBackfill = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerStreamingAggregationBackfill',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerStreamingAggregationBackfillRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerStreamingAggregationBackfillResponse.FromString,
                )
        self.TriggerFeaturesetDeletion = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerFeaturesetDeletion',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerFeaturesetDeletionRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerFeaturesetDeletionResponse.FromString,
                )
        self.GetExecutionStatus = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/GetExecutionStatus',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionStatusRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionStatusResponse.FromString,
                )
        self.GetExecutionEntry = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/GetExecutionEntry',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionEntryRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionEntryResponse.FromString,
                )
        self.GetRunningExecutionEntries = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/GetRunningExecutionEntries',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetRunningExecutionEntriesRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetRunningExecutionEntriesResponse.FromString,
                )
        self.InitPaginationByFeaturesetId = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/InitPaginationByFeaturesetId',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.InitPaginationByFeaturesetIdRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.InitPaginationByFeaturesetIdResponse.FromString,
                )
        self.ListExecutionsByFeaturesetId = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/ListExecutionsByFeaturesetId',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListExecutionsByFeaturesetIdRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListExecutionsByFeaturesetIdResponse.FromString,
                )
        self.ListLastExecutionsForEnvironment = channel.unary_unary(
                '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/ListLastExecutionsForEnvironment',
                request_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListLastExecutionsForEnvironmentRequest.SerializeToString,
                response_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListLastExecutionsForEnvironmentResponse.FromString,
                )


class FeatureStoreExecutionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def TriggerBatchBackfill(self, request, context):
        """Batch Featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerBatchFeatureset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOnlineStreamingIngestion(self, request, context):
        """Streaming Featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerOfflineStreamingIngestion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerRowLevelStreamingAggregationIngestion(self, request, context):
        """Streaming Aggregation Featureset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerCompactionStreamingAggregationIngestion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerStreamingAggregationBackfill(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerFeaturesetDeletion(self, request, context):
        """Deletion
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExecutionStatus(self, request, context):
        """Listings/ Paginated Listings /Getters
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExecutionEntry(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRunningExecutionEntries(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitPaginationByFeaturesetId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExecutionsByFeaturesetId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLastExecutionsForEnvironment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureStoreExecutionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'TriggerBatchBackfill': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerBatchBackfill,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBackfillRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBackfillResponse.SerializeToString,
            ),
            'TriggerBatchFeatureset': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerBatchFeatureset,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBatchFeaturesetRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBatchFeaturesetResponse.SerializeToString,
            ),
            'TriggerOnlineStreamingIngestion': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerOnlineStreamingIngestion,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOnlineStreamingIngestionRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOnlineStreamingIngestionResponse.SerializeToString,
            ),
            'TriggerOfflineStreamingIngestion': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerOfflineStreamingIngestion,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOfflineStreamingIngestionRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOfflineStreamingIngestionResponse.SerializeToString,
            ),
            'TriggerRowLevelStreamingAggregationIngestion': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerRowLevelStreamingAggregationIngestion,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerRowLevelStreamingAggregationIngestionRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerRowLevelStreamingAggregationIngestionResponse.SerializeToString,
            ),
            'TriggerCompactionStreamingAggregationIngestion': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerCompactionStreamingAggregationIngestion,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerCompactionStreamingAggregationIngestionRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerCompactionStreamingAggregationIngestionResponse.SerializeToString,
            ),
            'TriggerStreamingAggregationBackfill': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerStreamingAggregationBackfill,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerStreamingAggregationBackfillRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerStreamingAggregationBackfillResponse.SerializeToString,
            ),
            'TriggerFeaturesetDeletion': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerFeaturesetDeletion,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerFeaturesetDeletionRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerFeaturesetDeletionResponse.SerializeToString,
            ),
            'GetExecutionStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExecutionStatus,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionStatusRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionStatusResponse.SerializeToString,
            ),
            'GetExecutionEntry': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExecutionEntry,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionEntryRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionEntryResponse.SerializeToString,
            ),
            'GetRunningExecutionEntries': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRunningExecutionEntries,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetRunningExecutionEntriesRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetRunningExecutionEntriesResponse.SerializeToString,
            ),
            'InitPaginationByFeaturesetId': grpc.unary_unary_rpc_method_handler(
                    servicer.InitPaginationByFeaturesetId,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.InitPaginationByFeaturesetIdRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.InitPaginationByFeaturesetIdResponse.SerializeToString,
            ),
            'ListExecutionsByFeaturesetId': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExecutionsByFeaturesetId,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListExecutionsByFeaturesetIdRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListExecutionsByFeaturesetIdResponse.SerializeToString,
            ),
            'ListLastExecutionsForEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLastExecutionsForEnvironment,
                    request_deserializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListLastExecutionsForEnvironmentRequest.FromString,
                    response_serializer=qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListLastExecutionsForEnvironmentResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.feature.store.execution.v1.FeatureStoreExecutionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureStoreExecutionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def TriggerBatchBackfill(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerBatchBackfill',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBackfillRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBackfillResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerBatchFeatureset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerBatchFeatureset',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBatchFeaturesetRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerBatchFeaturesetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOnlineStreamingIngestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerOnlineStreamingIngestion',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOnlineStreamingIngestionRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOnlineStreamingIngestionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerOfflineStreamingIngestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerOfflineStreamingIngestion',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOfflineStreamingIngestionRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerOfflineStreamingIngestionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerRowLevelStreamingAggregationIngestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerRowLevelStreamingAggregationIngestion',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerRowLevelStreamingAggregationIngestionRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerRowLevelStreamingAggregationIngestionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerCompactionStreamingAggregationIngestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerCompactionStreamingAggregationIngestion',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerCompactionStreamingAggregationIngestionRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerCompactionStreamingAggregationIngestionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerStreamingAggregationBackfill(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerStreamingAggregationBackfill',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerStreamingAggregationBackfillRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerStreamingAggregationBackfillResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerFeaturesetDeletion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/TriggerFeaturesetDeletion',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerFeaturesetDeletionRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.TriggerFeaturesetDeletionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExecutionStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/GetExecutionStatus',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionStatusRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExecutionEntry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/GetExecutionEntry',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionEntryRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetExecutionEntryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRunningExecutionEntries(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/GetRunningExecutionEntries',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetRunningExecutionEntriesRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.GetRunningExecutionEntriesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitPaginationByFeaturesetId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/InitPaginationByFeaturesetId',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.InitPaginationByFeaturesetIdRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.InitPaginationByFeaturesetIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListExecutionsByFeaturesetId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/ListExecutionsByFeaturesetId',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListExecutionsByFeaturesetIdRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListExecutionsByFeaturesetIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLastExecutionsForEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.feature.store.execution.v1.FeatureStoreExecutionService/ListLastExecutionsForEnvironment',
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListLastExecutionsForEnvironmentRequest.SerializeToString,
            qwak_dot_execution_dot_v1_dot_execution__service__pb2.ListLastExecutionsForEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Dict, List

from qwak.clients.administration.eco_system.eco_system_utils import EcosystemUtils
from qwak.clients.feature_store import FeatureRegistryClient
from qwak.feature_store._common.feature_set_utils import (
    FeatureSetInfo,
    get_env_to_featuresets_mapping,
    get_feature_set_info,
)
from qwak.model.schema_entities import BaseFeature, FeatureStoreInput
from qwak.model.utils.feature_utils import extract_env_name, extract_featureset_name


def retrieve_fs_mapping(
    features: List[BaseFeature],
) -> Dict[str, Dict[str, FeatureSetInfo]]:
    """
    Retrieve the feature set info mapping.
    If one of the features is a FeatureStoreInput and is in a different environment from the current one, populate it using a single API call.
    Otherwise, retrieve each feature set info individually.
    The reasoning behind this logic is that if all required features are in the same environment, it's more efficient to retrieve only the necessary feature set, rather than all feature sets.
    * Assuming the feature name is fully qualified with the environment name
    :param features:
    :return: dict of environment name to dict of feature set name to FeatureSetInfo
    """
    current_env_name = EcosystemUtils().get_current_environment_name()
    features_manager_client = FeatureRegistryClient()

    if any(
        [
            feature
            for feature in features
            if isinstance(feature, FeatureStoreInput)
            and extract_env_name(feature.name) != current_env_name
        ]
    ):
        return get_env_to_featuresets_mapping(features_manager_client)
    else:
        return _retrieve_fs_info_one_by_one(
            features_manager_client, current_env_name, features
        )


def _retrieve_fs_info_one_by_one(
    features_manager_client: FeatureRegistryClient,
    current_env_name: str,
    features: List[BaseFeature],
) -> Dict[str, Dict[str, FeatureSetInfo]]:
    fs_info_cache: Dict[str, FeatureSetInfo] = dict()

    for feature in features:
        if isinstance(feature, FeatureStoreInput):
            feature_set_name = extract_featureset_name(feature.name).lower()
            if feature_set_name not in fs_info_cache:
                fs_info_cache[feature_set_name] = get_feature_set_info(
                    features_manager_client, feature_set_name
                )
    return {current_env_name: fs_info_cache}



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/ecosystem/jfrog/v0/token_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.ecosystem.jfrog.v0 import token_pb2 as qwak_dot_ecosystem_dot_jfrog_dot_v0_dot_token__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/ecosystem/jfrog/v0/token_service.proto\x12\x1dqwak.ecosystem.jfrog.token.v0\x1a#qwak/ecosystem/jfrog/v0/token.proto\"Y\n\x14GenerateTokenRequest\x12\x41\n\ntoken_spec\x18\x01 \x01(\x0b\x32-.qwak.ecosystem.jfrog.token.v0.JFrogTokenSpec\"Q\n\x15GenerateTokenResponse\x12\x38\n\x05token\x18\x01 \x01(\x0b\x32).qwak.ecosystem.jfrog.token.v0.JFrogToken\"|\n(GenerateArtifactoryImagePullTokenRequest\x12P\n\ntoken_spec\x18\x01 \x01(\x0b\x32<.qwak.ecosystem.jfrog.token.v0.ArtifactoryImagePullTokenSpec\"e\n)GenerateArtifactoryImagePullTokenResponse\x12\x38\n\x05token\x18\x01 \x01(\x0b\x32).qwak.ecosystem.jfrog.token.v0.JFrogToken\"`\n\x19PersistTokenClaimsRequest\x12\x43\n\x04spec\x18\x01 \x01(\x0b\x32\x35.qwak.ecosystem.jfrog.token.v0.PersistTokenClaimsSpec\".\n\x1aPersistTokenClaimsResponse\x12\x10\n\x08token_id\x18\x01 \x01(\t\"d\n\x12RevokeTokenRequest\x12N\n\x11token_revoke_spec\x18\x01 \x01(\x0b\x32\x33.qwak.ecosystem.jfrog.token.v0.JFrogTokenRevokeSpec\"\x1c\n\x1aRevokeTokenRequestResponse2\xcc\x04\n\x0cTokenService\x12z\n\rGenerateToken\x12\x33.qwak.ecosystem.jfrog.token.v0.GenerateTokenRequest\x1a\x34.qwak.ecosystem.jfrog.token.v0.GenerateTokenResponse\x12\xb6\x01\n!GenerateArtifactoryImagePullToken\x12G.qwak.ecosystem.jfrog.token.v0.GenerateArtifactoryImagePullTokenRequest\x1aH.qwak.ecosystem.jfrog.token.v0.GenerateArtifactoryImagePullTokenResponse\x12\x89\x01\n\x12PersistTokenClaims\x12\x38.qwak.ecosystem.jfrog.token.v0.PersistTokenClaimsRequest\x1a\x39.qwak.ecosystem.jfrog.token.v0.PersistTokenClaimsResponse\x12{\n\x0bRevokeToken\x12\x31.qwak.ecosystem.jfrog.token.v0.RevokeTokenRequest\x1a\x39.qwak.ecosystem.jfrog.token.v0.RevokeTokenRequestResponseB\xb7\x01\n\x1a\x63om.qwak.ai.jfrog.token.v0P\x01Z\x96\x01github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/jfrog/v0;jfrog_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.ecosystem.jfrog.v0.token_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.qwak.ai.jfrog.token.v0P\001Z\226\001github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/jfrog/v0;jfrog_v0'
  _globals['_GENERATETOKENREQUEST']._serialized_start=115
  _globals['_GENERATETOKENREQUEST']._serialized_end=204
  _globals['_GENERATETOKENRESPONSE']._serialized_start=206
  _globals['_GENERATETOKENRESPONSE']._serialized_end=287
  _globals['_GENERATEARTIFACTORYIMAGEPULLTOKENREQUEST']._serialized_start=289
  _globals['_GENERATEARTIFACTORYIMAGEPULLTOKENREQUEST']._serialized_end=413
  _globals['_GENERATEARTIFACTORYIMAGEPULLTOKENRESPONSE']._serialized_start=415
  _globals['_GENERATEARTIFACTORYIMAGEPULLTOKENRESPONSE']._serialized_end=516
  _globals['_PERSISTTOKENCLAIMSREQUEST']._serialized_start=518
  _globals['_PERSISTTOKENCLAIMSREQUEST']._serialized_end=614
  _globals['_PERSISTTOKENCLAIMSRESPONSE']._serialized_start=616
  _globals['_PERSISTTOKENCLAIMSRESPONSE']._serialized_end=662
  _globals['_REVOKETOKENREQUEST']._serialized_start=664
  _globals['_REVOKETOKENREQUEST']._serialized_end=764
  _globals['_REVOKETOKENREQUESTRESPONSE']._serialized_start=766
  _globals['_REVOKETOKENREQUESTRESPONSE']._serialized_end=794
  _globals['_TOKENSERVICE']._serialized_start=797
  _globals['_TOKENSERVICE']._serialized_end=1385
# @@protoc_insertion_point(module_scope)



from typing import Optional

from pydantic import BaseModel

from frogml_storage.models.entity_manifest import EntityManifest


class FrogMLEntityVersion(BaseModel):
    """
    Represent a metadata of uploaded entity

    Attributes:
        entity_name: The entity name (model | dataset)
        namespace: The namespace of the model | dataset
        version: The version of the model | dataset
        entity_manifest: The entity manifest file
    """

    entity_name: str
    namespace: Optional[str] = None
    version: str
    entity_manifest: Optional[EntityManifest] = None

    def __eq__(self, other):
        if not isinstance(other, FrogMLEntityVersion):
            return False
        if self.version != other.version:
            return False
        if self.namespace != other.namespace:
            return False
        if self.entity_name != other.entity_name:
            return False

        return True



from typing import Any

from requests import PreparedRequest
from requests.auth import AuthBase


class BearerAuth(AuthBase):
    def __init__(self, token: str):
        self.token: str = token

    def __call__(self, r: PreparedRequest) -> PreparedRequest:
        r.headers["Authorization"] = f"Bearer {self.token}"
        return r

    def __eq__(self, other: Any) -> bool:
        if not isinstance(other, BearerAuth):
            return False

        return self.token == other.token


class EmptyAuth(AuthBase):
    def __call__(self, r: PreparedRequest) -> PreparedRequest:
        return r



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ValidationSuccessResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SAMPLE_FIELD_NUMBER: builtins.int
    PANDAS_COLUMN_DESCRIPTION_FIELD_NUMBER: builtins.int
    SPARK_COLUMN_DESCRIPTION_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int
    sample: builtins.str
    """The sample of the success response"""
    @property
    def pandas_column_description(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PandasColumnDescription]:
        """The pandas column description of the success response"""
    @property
    def spark_column_description(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SparkColumnDescription]:
        """The spark column description of the success response"""
    @property
    def outputs(self) -> global___Outputs:
        """the outputs printed during the run"""
    def __init__(
        self,
        *,
        sample: builtins.str = ...,
        pandas_column_description: collections.abc.Iterable[global___PandasColumnDescription] | None = ...,
        spark_column_description: collections.abc.Iterable[global___SparkColumnDescription] | None = ...,
        outputs: global___Outputs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["outputs", b"outputs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["outputs", b"outputs", "pandas_column_description", b"pandas_column_description", "sample", b"sample", "spark_column_description", b"spark_column_description"]) -> None: ...

global___ValidationSuccessResponse = ValidationSuccessResponse

class PandasColumnDescription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_NAME_FIELD_NUMBER: builtins.int
    PANDAS_TYPE_FIELD_NUMBER: builtins.int
    column_name: builtins.str
    """The column name"""
    pandas_type: builtins.str
    """The pandas type of the column"""
    def __init__(
        self,
        *,
        column_name: builtins.str = ...,
        pandas_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_name", b"column_name", "pandas_type", b"pandas_type"]) -> None: ...

global___PandasColumnDescription = PandasColumnDescription

class SparkColumnDescription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLUMN_NAME_FIELD_NUMBER: builtins.int
    SPARK_TYPE_FIELD_NUMBER: builtins.int
    column_name: builtins.str
    """The column name"""
    spark_type: builtins.str
    """The spark type of the column"""
    def __init__(
        self,
        *,
        column_name: builtins.str = ...,
        spark_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_name", b"column_name", "spark_type", b"spark_type"]) -> None: ...

global___SparkColumnDescription = SparkColumnDescription

class ValidationFailureResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PHASE_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int
    phase: builtins.str
    """The phase in which the validation failed in"""
    error_message: builtins.str
    """The error message of the failure"""
    description: builtins.str
    """The error message description"""
    @property
    def outputs(self) -> global___Outputs:
        """the outputs printed during the run"""
    def __init__(
        self,
        *,
        phase: builtins.str = ...,
        error_message: builtins.str = ...,
        description: builtins.str = ...,
        outputs: global___Outputs | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["outputs", b"outputs"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "error_message", b"error_message", "outputs", b"outputs", "phase", b"phase"]) -> None: ...

global___ValidationFailureResponse = ValidationFailureResponse

class Outputs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STDOUT_FIELD_NUMBER: builtins.int
    STDERR_FIELD_NUMBER: builtins.int
    stdout: builtins.str
    """the stdout printed during the run"""
    stderr: builtins.str
    """the stderr printed during the run"""
    def __init__(
        self,
        *,
        stdout: builtins.str = ...,
        stderr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["stderr", b"stderr", "stdout", b"stdout"]) -> None: ...

global___Outputs = Outputs

class ValidationNotReadyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ValidationNotReadyResponse = ValidationNotReadyResponse



from typing import Callable

import grpc
from _qwak_proto.qwak.service_discovery.service_discovery_location_pb2 import (
    ServiceLocationDescriptor,
)
from _qwak_proto.qwak.service_discovery.service_discovery_location_service_pb2 import (
    GetServingUrlRequest as ProtoGetServingUrlRequest,
    GetServingUrlRequestResponse as ProtoGetServingUrlRequestResponse,
)
from _qwak_proto.qwak.service_discovery.service_discovery_location_service_pb2_grpc import (
    LocationDiscoveryServiceStub,
)
from dependency_injector.wiring import Provide
from qwak.exceptions import QwakException
from qwak.inner.di_configuration import QwakContainer


class LocationDiscoveryClient:
    """
    Client for querying service locations from the LocationDiscoveryService.
    """

    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self._service = LocationDiscoveryServiceStub(grpc_channel)

    @staticmethod
    def _get_location(
        method: Callable[
            [ProtoGetServingUrlRequest], ProtoGetServingUrlRequestResponse
        ],
    ) -> ServiceLocationDescriptor:
        """
        Calls a specific RPC and extracts the service location descriptor.

        Args:
            method: The gRPC method to call.

        Returns:
            ServiceLocationDescriptor: Contains service_url and location metadata.
        """
        try:
            request = ProtoGetServingUrlRequest()
            response = method(request)
            return response.location
        except grpc.RpcError as e:
            raise QwakException(
                f"Failed to retrieve service location. Error is: {e.details()}"
            ) from e

    def get_offline_serving(self) -> ServiceLocationDescriptor:
        """Fetches the offline serving service location."""
        return self._get_location(self._service.GetOfflineServingUrl)

    def get_distribution_manager(self) -> ServiceLocationDescriptor:
        """Fetches the distribution manager service location."""
        return self._get_location(self._service.GetDistributionManagerUrl)

    def get_analytics_engine(self) -> ServiceLocationDescriptor:
        """Fetches the analytics engine service location."""
        return self._get_location(self._service.GetAnalyticsEngineUrl)

    def get_metrics_gateway(self) -> ServiceLocationDescriptor:
        """Fetches the metrics gateway service location."""
        return self._get_location(self._service.GetMetricsGatewayUrl)

    def get_features_operator(self) -> ServiceLocationDescriptor:
        """Fetches the features operator service location."""
        return self._get_location(self._service.GetFeaturesOperatorUrl)

    def get_hosting_gateway(self) -> ServiceLocationDescriptor:
        """Fetches the hosting gateway service location."""
        return self._get_location(self._service.GetHostingGatewayUrl)



#
#    Copyright 2024 OpenAI
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.

from __future__ import annotations

from dataclasses import dataclass
from typing import Dict, Iterable, List, Optional, Union

from typing_extensions import Literal, Required, TypedDict

__all__ = [
    "CompletionCreateParamsBase",
    "CompletionCreateParamsNonStreaming",
    "CompletionCreateParamsStreaming",
]


class CompletionCreateParamsBase(TypedDict, total=False):
    model: Required[
        Union[str, Literal["gpt-3.5-turbo-instruct", "davinci-002", "babbage-002"]]
    ]
    """ID of the model to use.

    You can use the
    [List models](https://platform.openai.com/docs/api-reference/models/list) API to
    see all of your available models, or see our
    [Model overview](https://platform.openai.com/docs/models/overview) for
    descriptions of them.
    """

    prompt: Required[
        Union[str, List[str], Iterable[int], Iterable[Iterable[int]], None]
    ]
    """
    The prompt(s) to generate completions for, encoded as a string, array of
    strings, array of tokens, or array of token arrays.

    Note that <|endoftext|> is the document separator that the model sees during
    training, so if a prompt is not specified the model will generate as if from the
    beginning of a new document.
    """

    best_of: Optional[int]
    """
    Generates `best_of` completions server-side and returns the "best" (the one with
    the highest log probability per token). Results cannot be streamed.

    When used with `n`, `best_of` controls the number of candidate completions and
    `n` specifies how many to return – `best_of` must be greater than `n`.

    **Note:** Because this parameter generates many completions, it can quickly
    consume your token quota. Use carefully and ensure that you have reasonable
    settings for `max_tokens` and `stop`.
    """

    echo: Optional[bool]
    """Echo back the prompt in addition to the completion"""

    frequency_penalty: Optional[float]
    """Number between -2.0 and 2.0.

    Positive values penalize new tokens based on their existing frequency in the
    text so far, decreasing the model's likelihood to repeat the same line verbatim.

    [See more information about frequency and presence penalties.](https://platform.openai.com/docs/guides/text-generation/parameter-details)
    """

    logit_bias: Optional[Dict[str, int]]
    """Modify the likelihood of specified tokens appearing in the completion.

    Accepts a JSON object that maps tokens (specified by their token ID in the GPT
    tokenizer) to an associated bias value from -100 to 100. You can use this
    [tokenizer tool](/tokenizer?view=bpe) to convert text to token IDs.
    Mathematically, the bias is added to the logits generated by the model prior to
    sampling. The exact effect will vary per model, but values between -1 and 1
    should decrease or increase likelihood of selection; values like -100 or 100
    should result in a ban or exclusive selection of the relevant token.

    As an example, you can pass `{"50256": -100}` to prevent the <|endoftext|> token
    from being generated.
    """

    logprobs: Optional[int]
    """
    Include the log probabilities on the `logprobs` most likely output tokens, as
    well the chosen tokens. For example, if `logprobs` is 5, the API will return a
    list of the 5 most likely tokens. The API will always return the `logprob` of
    the sampled token, so there may be up to `logprobs+1` elements in the response.

    The maximum value for `logprobs` is 5.
    """

    max_tokens: Optional[int]
    """
    The maximum number of [tokens](/tokenizer) that can be generated in the
    completion.

    The token count of your prompt plus `max_tokens` cannot exceed the model's
    context length.
    [Example Python code](https://cookbook.openai.com/examples/how_to_count_tokens_with_tiktoken)
    for counting tokens.
    """

    n: Optional[int]
    """How many completions to generate for each prompt.

    **Note:** Because this parameter generates many completions, it can quickly
    consume your token quota. Use carefully and ensure that you have reasonable
    settings for `max_tokens` and `stop`.
    """

    presence_penalty: Optional[float]
    """Number between -2.0 and 2.0.

    Positive values penalize new tokens based on whether they appear in the text so
    far, increasing the model's likelihood to talk about new topics.

    [See more information about frequency and presence penalties.](https://platform.openai.com/docs/guides/text-generation/parameter-details)
    """

    seed: Optional[int]
    """
    If specified, our system will make a best effort to sample deterministically,
    such that repeated requests with the same `seed` and parameters should return
    the same result.

    Determinism is not guaranteed, and you should refer to the `system_fingerprint`
    response parameter to monitor changes in the backend.
    """

    stop: Union[Optional[str], List[str], None]
    """Up to 4 sequences where the API will stop generating further tokens.

    The returned text will not contain the stop sequence.
    """

    suffix: Optional[str]
    """The suffix that comes after a completion of inserted text.

    This parameter is only supported for `gpt-3.5-turbo-instruct`.
    """

    temperature: Optional[float]
    """What sampling temperature to use, between 0 and 2.

    Higher values like 0.8 will make the output more random, while lower values like
    0.2 will make it more focused and deterministic.

    We generally recommend altering this or `top_p` but not both.
    """

    top_p: Optional[float]
    """
    An alternative to sampling with temperature, called nucleus sampling, where the
    model considers the results of the tokens with top_p probability mass. So 0.1
    means only the tokens comprising the top 10% probability mass are considered.

    We generally recommend altering this or `temperature` but not both.
    """

    user: str
    """
    A unique identifier representing your end-user, which can help OpenAI to monitor
    and detect abuse.
    [Learn more](https://platform.openai.com/docs/guides/safety-best-practices/end-user-ids).
    """


@dataclass
class CompletionCreateParamsNonStreaming(CompletionCreateParamsBase):
    stream: Optional[Literal[False]]
    """Whether to stream back partial progress.

    If set, tokens will be sent as data-only
    [server-sent events](https://developer.mozilla.org/en-US/docs/Web/API/Server-sent_events/Using_server-sent_events#Event_stream_format)
    as they become available, with the stream terminated by a `data: [DONE]`
    message.
    [Example Python code](https://cookbook.openai.com/examples/how_to_stream_completions).
    """


@dataclass
class CompletionCreateParamsStreaming(CompletionCreateParamsBase):
    stream: Required[Literal[True]]
    """Whether to stream back partial progress.

    If set, tokens will be sent as data-only
    [server-sent events](https://developer.mozilla.org/en-US/docs/Web/API/Server-sent_events/Using_server-sent_events#Event_stream_format)
    as they become available, with the stream terminated by a `data: [DONE]`
    message.
    [Example Python code](https://cookbook.openai.com/examples/how_to_stream_completions).
    """


CompletionCreateParams = Union[
    CompletionCreateParamsNonStreaming, CompletionCreateParamsStreaming
]
